/***********************************************************
*  Module       : JavaScript
*  Language     : ES Spanish
*  Version      : vt5.0.4
*  Created Date : 2008-01-18 17:46:07
*  Author       : JPL TSolucio, S.L.  -  rasomu
*  Last change  : 2008-01-18
*  Author       : Joe Bordes JPL TSolucio, S.L.
***********************************************************/

var alert_arr = {
      DELETE:'¿Borrar los ',
      RECORDS:' registros?',
      SELECT:'Introduzca, al menos, una entidad',
      DELETE_ACCOUNT:'Borrar esta cuenta eliminará las Oportunidades y Presupuestos que tenga asociadas. ¿Continuar borrando los ',
      DELETE_VENDOR:'Borrar este proveedor eliminará las Órdenes de Compra que tenga Asociadas. ¿Continuar borrando los ',
      SELECT_MAILID:'Seleccione un Email Id',
      OVERWRITE_EXISTING_ACCOUNT1:'¿Sobreescribir la dirección existente con la dirección de la cuenta seleccionada (',
      OVERWRITE_EXISTING_ACCOUNT2:')?',
      OVERWRITE_EXISTING_CONTACT1:'¿Sobreescribir la dirección existente con la dirección del contacto seleccionado (',
      OVERWRITE_EXISTING_CONTACT2:')?',
      MISSING_FIELDS:'Faltan Campos Obligatorios:',
      NOT_ALLOWED_TO_EDIT:'no está autorizado a editar este campo',
      NOT_ALLOWED_TO_EDIT_FIELDS:'no está autorizado a editar los campos',
      COLUMNS_CANNOT_BE_EMPTY:'Las Columnas seleccionadas no pueden estar vacias',
      CANNOT_BE_EMPTY:' no puede estar vacia',
      CANNOT_BE_NONE:' no puede ser ninguno',
      ENTER_VALID:'Seleccione un válido ',
      SHOULDBE_LESS:' debe ser menor que ',
      SHOULDBE_LESS_EQUAL:' debe ser menor o igual a',
      SHOULDBE_EQUAL:' debe ser igual a ',
      SHOULDBE_GREATER:' debe ser mayor que ',
      SHOULDBE_GREATER_EQUAL:' debe ser mayor o igual a ',
      INVALID:'Inválido ',
      EXCEEDS_MAX:' Supera el límite máximo ',
      OUT_OF_RANGE:' está fuera de rango',
      SHOULDNOTBE_EQUAL:' no debe ser igual a ',
      PORTAL_PROVIDE_EMAILID:'Usuario del portal debe tener un email válido',
      ADD_CONFIRMATION:'¿Añadir los seleccionados ',
      ACCOUNTNAME_CANNOT_EMPTY:'El nombre de cuenta no puede estar vacío',
      CANT_SELECT_CONTACTS:'No puede seleccionar contactos relacionados desde un Pre-Contacto',
      LBL_THIS:'Este ',
      DOESNOT_HAVE_MAILIDS:' no tiene email',
      ARE_YOU_SURE:'¿Seguro?',
      DOESNOT_HAVE_AN_MAILID:'" no tiene email',
      MISSING_REQUIRED_FIELDS:'Faltan Campos Obligatorios: ',
      READONLY:'Es de solo lectura',
      SELECT_ATLEAST_ONE_USER:'Seleccione un usuario, al menos',
      DISABLE_SHARING_CONFIRMATION:'Desactivar compartidos para los usuarios seleccionados ',
      USERS:' ?',
      ENDTIME_GREATER_THAN_STARTTIME:'La hora de finalización debe ser posterior a la de inicio ',
      FOLLOWUPTIME_GREATER_THAN_STARTTIME:'La hora de repetición debe ser posterior a la de finalización ',
      MISSING_EVENT_NAME:'Falta nombre del Evento',
      EVENT_TYPE_NOT_SELECTED:'No ha seleccionado Tipo de Evento',
      CLOSEDATE_CANNOT_BE_EMPTY:'La Fecha de Cierre no puede estar vacía',
      SITEURL_CANNOT_BE_EMPTY:'La Dirección Web no puede estar vacía',
      SITENAME_CANNOT_BE_EMPTY:'La Página Web no puede estar vacía',
      LISTPRICE_CANNOT_BE_EMPTY:'La Tarifa no puede estar vacía',
      INVALID_LIST_PRICE:'Tarifa Inválida',
      PROBLEM_ACCESSSING_URL:'Problema accediendo a la URL: ',
      CODE:' Código: ',
      WISH_TO_QUALIFY_MAIL_AS_CONTACT:'¿Quiere calificar este email como contacto?',
      SELECT_ATLEAST_ONEMSG_TO_DEL:'Seleccione, al menos, un email para borrar',
      ERROR:'Error',
      FIELD_TYPE_NOT_SELECTED:'Tipo de Campo no seleccionado',
      SPECIAL_CHARACTERS_NOT_ALLOWED:'No se admiten caracteres especiales en el campo Etiqueta',
      SPECIAL_CHARACTERS:'Caracteres especiales',
      NOT_ALLOWED:'no estan permitidos. Intenta con otros valores.',
      PICKLIST_CANNOT_BE_EMPTY:'El Valor del Desplegable no puede estar vacío',
      DUPLICATE_VALUES_FOUND:'Encontrados Valores Duplicados',
      DUPLICATE_MAPPING_ACCOUNTS:'¡Asignación Duplicada en Cuentas!',
      DUPLICATE_MAPPING_CONTACTS:'¡Asignación Duplicada en Contactos!',
      DUPLICATE_MAPPING_POTENTIAL:'¡Asignación Duplicada en Oportunidades!',
      ERROR_WHILE_EDITING:'Error Editando',
      CURRENCY_CHANGE_INFO:'Cambio de Moneda Realizado correctamente',
      CURRENCY_CONVERSION_INFO:'¿Está usando el Dolar como moneda? \n Pulse OK para mantener $, Cancelar para cambiar el ratio de conversión.',
      THE_EMAILID:'El email id \\\'',
      EMAIL_FIELD_INVALID:'\\\' en el campo email es inválido',
      MISSING_REPORT_NAME:'Falta el Nombre del Informe',
      REPORT_NAME_EXISTS:'El nombre del informe existe, use otro...',
      WANT_TO_CHANGE_CONTACT_ADDR:'¿Cambiar las direcciones de los Contactos relacionados con esta Cuenta?',
      SURE_TO_DELETE:'¿Borrar?',
      NO_PRODUCT_SELECTED:'No hay productos seleccionados, Elija uno.',
      VALID_FINAL_PERCENT:'Introduzca un Porcentaje de Descuento válido',
      VALID_FINAL_AMOUNT:'Introduzca un Importe Final válido',
      VALID_SHIPPING_CHARGE:'Introduzca un Cargo por Manipulado y Transporte válido',
      VALID_ADJUSTMENT:'Introduzca un ajuste válido',
      WANT_TO_CONTINUE:'¿Quiere continuar?',
      ENTER_VALID_TAX:'Introduzca un Valor de Impuesto válido',
      VALID_TAX_NAME:'Introduzca un Nombre de Impuesto válido',
      CORRECT_TAX_VALUE:'Introduzca un Valor de Impuesto correcto',
      ENTER_POSITIVE_VALUE:'Introduzca un Valor positivo',
      LABEL_SHOULDNOT_EMPTY:'El nombre del Impuesto no puede estar vacío',
      NOT_VALID_ENTRY:'no es una entrada válida. Introduzca un valor correcto.',
      VALID_DISCOUNT_PERCENT:'Introduzca un Porcentaje de Descuento válido',
      VALID_DISCOUNT_AMOUNT:'Introduzca un Importe de Descuento válido',
      SELECT_TEMPLATE_TO_MERGE:'Seleccione una plantilla para combinar',
      SELECTED_MORE_THAN_ONCE:'Ha seleccionado este elemento más de una vez.',
      YES:'si',
      NO:'no',
      MAIL:'mail',
      EQUALS:'igual',
      NOT_EQUALS_TO:'no igual a',
      STARTS_WITH:'empieza con',
      CONTAINS:'contiene',
      DOES_NOT_CONTAINS:'no contiene',
      LESS_THAN:'menor que',
      GREATER_THAN:'mayor que',
      LESS_OR_EQUALS:'menor o igual',
      GREATER_OR_EQUALS:'mayor o igual',
      NO_SPECIAL_CHARS:'No se admiten caracteres especiales en la cadena de la factura',
      PLS_SELECT_VALID_FILE:'Seleccione un archivo con las siguientes extensiones:\n',
      NO_SPECIAL:'Caracteres especiales no permitidos',
      NO_QUOTES:'Comillas (\' ") y el símbolo de sumar (+) no permitidos ',
      IN_PROFILENAME:' en Nombre de Perfil',
      IN_GROUPNAME:' en Nombre de Grupo',
      IN_ROLENAME:' en Nombre de Rol',
      VALID_TAX_PERCENT:'Introduzca un Porcentaje de Impuesto válido',
      VALID_SH_TAX:'Introduzca un Impuesto válido para Manipulación y Transportes',
      ROLE_DRAG_ERR_MSG:'No puede mover un Nodo Padre bajo un Nodo Hijo',
      LBL_DEL:'Supr',
      VALID_DATA:' Introduzca una fecha válida. ',
      STDFILTER:'Filtros Estandar',
      STARTDATE:'Fecha de Inicio',
      ENDDATE:'Fecha de Fin',
      START_DATE_TIME:'Fecha y Hora de Inicio',
      START_TIME:'Hora de Inicio',
      DATE_SHOULDNOT_PAST:'Fecha y Hora para Actividades con Estatus Planeada',
      TIME_SHOULDNOT_PAST:'Hora para Actividades con Estatus Planeada',
      LBL_AND:'y',
      LBL_ENTER_VALID_PORT:'Introduzca un Nº de puerto válido',
      IN_USERNAME:' en Usuario ',
      LBL_ENTER_VALID_NO:'Introduzca un número',
      LBL_PROVIDE_YES_NO:' Valor incorrecto.\n introduzca YES o NO',
      LBL_SELECT_CRITERIA:'Criterio Invalido.\n Elija otro criterio',
      OPPORTUNITYNAME_CANNOT_BE_EMPTY:'El nombre de la Oportunidad no puede estar vacío',
      OVERWRITE_EXISTING_ACCOUNT1:'¿Sobreescribir la dirección existente con la de la cuenta (',
      NAME_DESC:' para Nombre de Carpeta y Descripción',
      ENDS_WITH:'termina con',
      SHARED_EVENT_DEL_MSG:'El usuario no está autorizado a eliminar el registro.',
      LBL_WRONG_IMAGE_TYPE:'Los tipos de archivo permitidos son: jpeg, png, jpg, pjpeg, x-png or gif',
      SELECT_MAIL_MOVE:'Seleccionar correo y mover',
      LBL_NOTSEARCH_WITHSEARCH_ALL:'No ha usado la búsqueda. Todos los registros serán exportados desde ',
      LBL_NOTSEARCH_WITHSEARCH_CURRENTPAGE:'No ha buscado nada. Pero ha seleccionado con una búsqueda y <br> página actual. Los registros de la página actual se<br> exportarán desde ',
      LBL_NO_DATA_SELECTED:'No hay registros seleccionados. Seleccione, al menos, un registro a exportar',
      LBL_SEARCH_WITHOUTSEARCH_ALL:'You have used search option but you have not selected without search & all options.\n You can click [ok] to export all data or  You can click [cancel] and try again with other export criteria',
      STOCK_IS_NOT_ENOUGH:'No hay suficiente Stock',
      INVALID_QTY:'Cantidad Inválida',
      LBL_SEARCH_WITHOUTSEARCH_CURRENTPAGE:'You have used search option but you have not selected without search & currentpage options.\n You can click [ok]to export  current page data or You can click [cancel] and try again with some other export criteria.',
      LBL_SELECT_COLUMN:'Columna inválida.\nSelecciona columna.',
      LBL_NOT_ACCESSIBLE:'No Accesible',
      LBL_FILENAME_LENGTH_EXCEED_ERR:'El nombre del fichero no puede contener más de 255 caracteres.',
      LBL_DONT_HAVE_EMAIL_PERMISSION:'No tienes permiso para acceder al campo de email.',
      LBL_NO_FEEDS_SELECTED:'No se ha seleccionado una difusión',
      LBL_SELECT_PICKLIST:'Por favor selecciona al menos un valor para borrar',
      LBL_CANT_REMOVE:'No se pueden eliminar todos los valores',

      // Added after 5.0.4 GA
      /*For global add/delete in picklist*/
      LBL_GIVE_PICKLIST_VALUE:'Añade algún valor a la lista de selección',
      LBL_SELECT_ROLE:'Selecciona al menos un rol que verá los nuevos valores',
      LBL_ADD_PICKLIST_VALUE:'Añade al menos un nuevo valor',
      LBL_NO_VALUES_TO_DELETE: "no hay valores para eliminar",

      /* For Duplicate merging feature */
      SAME_GROUPS: 'Tienes que seleccionar los registros en el mismo grupo para combinar',
      ATLEAST_TWO: 'Selecciona al menos dos registros para combinar',
      MAX_THREE: 'Está permitido seleccionar un máximo de tres registros',
      //PARENT_RECORD: 'Selecciona un registro como registro paterno',  MergeFields.tpl Line:59
      MAX_RECORDS: 'Está permitido seleccionar un máximo de cuatro registros',
      CON_MANDATORY: 'Selecciona el campo obligatorio Apellido',
      LE_MANDATORY: 'Selecciona el campo obligatorio Apellido y Compañía',
      ACC_MANDATORY: 'Selecciona el campo obligatorio Nombre Cuenta',
      PRO_MANDATORY: 'Selecciona el campo obligatorio Nombre Producto',
      TIC_MANDATORY: 'Selecciona el campo obligatorio Título Incidencia',
      POTEN_MANDATORY: 'Selecciona el campo obligatorio Nombre Potencial',
      VEN_MANDATORY: 'Selecciona el campo obligatorio Nombre Proveedor',
      DEL_MANDATORY: 'No está permitido eliminar el campo obligatorio',

      /* For Multi-Currency Support */
      MSG_CHANGE_CURRENCY_REVISE_UNIT_PRICE: 'El precio unitario de todas las monedas se actualizará basándose en la moneda seleccionada. ¿Estás seguro?',

      Select_one_record_as_parent_record : 'Selecciona un registro como entidad superior',
      RECURRING_FREQUENCY_NOT_PROVIDED : 'Frecuencia de recurrencia no establecida',
      RECURRING_FREQNECY_NOT_ENABLED : 'Frecuencia de recurrencia establecida, pero recursión no activada',
      /* Added for Documents module */
      NO_SPECIAL_CHARS_DOCS:'Caracteres especiales como comillas, barra invertida, suma +, porcentaje % e interrogante ? no están permitidos',
      FOLDER_NAME_TOO_LONG:'Nombre de carpeta demasiado largo. Inténtalo de nuevo!',
      FOLDERNAME_EMPTY:'Nombre de carpeta vacío.',
      DUPLICATE_FOLDER_NAME:'Nombre de carpeta ya existe. Inténtalo de nuevo!',
      FOLDER_DESCRIPTION_TOO_LONG:'Descripción de carpeta demasiada larga. Inténtalo de nuevo!',
      NOT_PERMITTED:"No tienes permiso para ejecutar esta operación.",

      ALL_FILTER_CREATION_DENIED:'No se puede crear un filtro de nombre "All"/"Todo", utiliza un nombre diferente',
      OPERATION_DENIED:'No tiene permiso para realizar esta operación',
      EMAIL_CHECK_MSG: 'Deshabilita el acceso al portal para poder dejar vacío el campo de cuenta de correo',
      IS_PARENT : 'Este producto tiene sub-productos, no está permitido asignarle un producto superior o paterno',

      /*global actions on picklist*/
      PICKLIST_CANNOT_BE_EMPTY: 'Valor de la lista no puede quedar vacío',
      DUPLICATE_VALUES_FOUND: 'Se han encontrado valores duplicados',
      LBL_NO_ROLES_SELECTED: 'No se ha seleccionado ningún rol. ¿Quieres continuar?',
      LBL_DUPLICATE_FOUND: 'Entrada duplicada encontrada para el valor ',
      LBL_CANNOT_HAVE_EMPTY_VALUE: 'No se puede tener valor nulo. Para eliminar, retrocede y pulsa el botón de eliminar',
      LBL_DUPLICATE_VALUE_EXISTS: 'Valores duplicados existen',
      LBL_WANT_TO_DELETE: "Esto eliminará los valores de selección marcados para todos los roles. ¿Estás seguro de continuar? ",
      LBL_DELETE_ALL_WARNING: "Has marcado para eliminar todos los valores de selección. ¿Estás seguro de continuar?",
      LBL_PLEASE_CHANGE_REPLACEMENT: "por favor cambia el valor de sustitución; también está seleccionado para eliminación",

      /*layout Editor changes*/
      BLOCK_NAME_CANNOT_BE_BLANK : 'El nombre del bloque no puede quedar vacío',
      ARE_YOU_SURE_YOU_WANT_TO_DELETE : '¿Estás seguro que quieres eliminar?',
      PLEASE_MOVE_THE_FIELDS_TO_ANOTHER_BLOCK : 'Por favor mueve los campos a otro bloque',
      ARE_YOU_SURE_YOU_WANT_TO_DELETE_BLOCK : '¿Estás seguro que quieres eliminar el bloque?',
      LABEL_CANNOT_NOT_EMPTY : 'La etiqueta no puede quedar vacía',
      LBL_TYPEALERT_1 : 'No se puede vincular',
      LBL_WITH : 'con el tipo de dato',
      LBL_TYPEALERT_2 : '. Vincula siempre tipos de datos equivalentes.',
      LBL_LENGTHALERT : 'No está permitido vincular campos con diferente número de caracteres. Trate de vincular los datos con igual o más número de caracteres.',
      LBL_DECIMALALERT : 'No está permitido vincular campos con diferente número de decimales. Trate de vincular los datos con igual o más número de decimales.',
      FIELD_IS_MANDATORY : 'Campo obligatorio',
      FIELD_IS_ACTIVE : 'Campo disponible',
      FIELD_IN_QCREATE : 'Disponible en Creación Rápida',
      FIELD_IS_MASSEDITABLE : 'Disponible para Edición Masiva',

      IS_MANDATORY_FIELD : 'es Campo Obligatorio',
      CLOSEDATE_CANNOT_BE_EMPTY : 'Fecha Cierre no puede quedar vacío',
      AMOUNT_CANNOT_BE_EMPTY : 'Cantidad no puede quedar vacío',
      ARE_YOU_SURE : '¿Estás seguro que quieres eliminar?',
      LABEL_ALREADY_EXISTS : 'Etiqueta ya existe. Por favor introduce una etiqueta diferente',
      LENGTH_OUT_OF_RANGE : 'La longitud del Bloque debe ser inferior a los 50 caracteres',
      LBL_SELECT_ONE_FILE : 'Por favor selecciona al menos un fichero',
      LBL_UNABLE_TO_ADD_FOLDER : 'No se ha podido añadir la Carpeta. Por favor intentalo otra vez.',
      LBL_ARE_YOU_SURE_YOU_WANT_TO_DELETE_FOLDER : '¿Estas seguro que quieres eliminar la carpeta?',
      LBL_ERROR_WHILE_DELETING_FOLDER : 'Error eliminando la carpeta. Por favor intentalo otra vez.',
      LBL_FILE_CAN_BE_DOWNLOAD : 'Fichero disponible para descarga',
      LBL_DOCUMENT_LOST_INTEGRITY:'Documento no disponible. Se marcará como Inactivo',
      LBL_DOCUMENT_NOT_AVAILABLE : 'Fichero no disponible para descarga',
      LBL_FOLDER_SHOULD_BE_EMPTY : 'La carpeta ha de estar vacía para eliminarla!',

      LBL_PLEASE_SELECT_FILE_TO_UPLOAD : 'Por favor selecciona el fichero a cargar.',
      LBL_ARE_YOU_SURE_TO_MOVE_TO : '¿Estás seguro que quieres mover los ficheros a la carpeta ',
      LBL_FOLDER : '',
      LBL_UNABLE_TO_UPDATE : 'No se ha podido actualizar! Por favor intentalo otra vez.',
      LBL_BLANK_REPLACEMENT: 'No se puede seleccionar un valor vacío como sustitución',

      LBL_IMAGE_DELETED : 'Imagen Eliminada',

      /* Tooltip management */
      ERR_FIELD_SELECTION : 'Errores en la selección de campos',

      /* Inventory validation strings */
      NO_LINE_ITEM_SELECTED : 'No hay ninguna línea seleccionada. Por favor selecciona al menos una línea.',
      LINE_ITEM : 'Línea',
      LIST_PRICE: 'Precio Lista',
      
      /* Webmails */
      LBL_PRINT_EMAIL : 'Imprimir',
      LBL_DELETE_EMAIL : 'Borrar',
      LBL_DOWNLOAD_ATTACHMENTS : 'Descargar Adjuntos',
      LBL_QUALIFY_EMAIL : 'Clasificar',
      LBL_FORWARD_EMAIL : 'Reenviar',
      LBL_REPLY_TO_SENDER : 'Responder',
      LBL_REPLY_TO_ALL : 'Responder a todos',

      LBL_WIDGET_HIDDEN : 'Elemento escondido',
      LBL_RESTORE_FROM_PREFERENCES : 'Se puede habilitar en tus preferencias',
      ERR_HIDING : 'Error al esconder',
      MSG_TRY_AGAIN : 'Por favor intentalo otra vez',

      MSG_ENABLE_SINGLEPANE_VIEW : 'Vista sin Pestañas Habilitada',
      MSG_DISABLE_SINGLEPANE_VIEW : 'Vista sin Pestañas Deshabilitada',

      MSG_FTP_BACKUP_DISABLED : 'Copia FTP Deshabilitada',
      MSG_LOCAL_BACKUP_DISABLED : 'Copia Local Deshabilitada',
      MSG_FTP_BACKUP_ENABLED : 'Copia FTP Habilitada',
      MSG_LOCAL_BACKUP_ENABLED : 'Copia Local Habilitada',
      MSG_CONFIRM_PATH : 'confirma detalles Directorio',
      MSG_CONFIRM_FTP_DETAILS : 'confirma detalles FTP',

      START_PERIOD_END_PERIOD_CANNOT_BE_EMPTY : 'Periodo inicial o final no pueden quedar vacíos',

      /* added to fix i18n issues with home page*/
      LBL_ADD: 'Añadir ',
      Module: 'Módulo',
      DashBoard: 'Cuadro Mando',
      RSS: 'RSS',
      Default: 'Defecto',
      Notebook: 'Bloc Notas',
      SPECIAL_CHARS:'\\ / < > + \' " ',

      BETWEEN: 'entre',
      BEFORE: 'antes',
      AFTER: 'después',
      'ERROR_DELETING_TRY_AGAIN': 'Error eliminando. Por favor inténtalo otra vez.',
      'LBL_ENTER_WINDOW_TITLE': 'Introduce el título de la ventana.',
      'LBL_SELECT_ONLY_FIELDS': 'Selecciona solo dos campos.',
      'LBL_ENTER_RSS_URL':'Introduce la URL del RSS',
      'LBL_ADD_HOME_WIDGET': 'No se ha podido añadir elementos a la portada! Por favor inténtalo otra vez.',

      'LBL_DEFAULT_VALUE_FOR_THIS_FIELD' : 'Valor por defecto de este campo',

      'RECIPIENTS_CANNOT_BE_EMPTY' : 'Los destinatarios no puede quedar vacío',
      'VALID_SCANNER_NAME' : 'Introduce un nombre de clasificador válido (Solo Caracteres y Números)',
      'ERR_SAME_SOURCE_AND_TARGET' : 'El campo origen y destino no pueden ser el mismo',
      'ERR_ATLEAST_ONE_VALUE_FOR' : 'Has de seleccionar al menos un valor para',
      'ERR_SELECT_MODULE_FOR_DEPENDENCY' : 'Selecciona un módulo para añadir Dependencia'

};
